@@ -1,6 +1,6 @@
 /*
  * This file is part of dm-writeboost
- * Copyright (C) 2012-2018 Akira Hayakawa <ruby.wktk@gmail.com>
+ * Copyright (C) 2012-2020 Akira Hayakawa <ruby.wktk@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -507,7 +507,7 @@ static int format_all_segment_headers(struct wb_device *wb)
 		goto bad;
 	}
 
-	err = blkdev_issue_flush(dev->bdev, GFP_KERNEL, NULL);
+	err = dm_blkdev_issue_flush(dev->bdev, GFP_KERNEL);
 
 bad:
 	mempool_free(buf, wb->buf_8_pool);
